Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetECSTaskId ¶ added in v1.10.40
func GetECSTaskId() string
func New ¶
func New(domain, service, region, account, ec2Document, ec2Signature string, useRegionalSTS, omitDomain bool, rolePath string) (string, error)
New creates a new AttestationData with values fed to it and from the result of STS Assume Role. This requires an identity document along with its signature. The aws account and region will be extracted from the identity document.
Types ¶
type AttestationData ¶
type AttestationData struct {
Role string `json:"role,omitempty"` //the IAM role. This must match the athenz service identity
CommonName string `json:"commonName,omitempty"` //The common name for CSR. Different from Role if we're using service name only
Access string `json:"access,omitempty"` //the temp creds access key id
Secret string `json:"secret,omitempty"` //the temp creds secret key
Token string `json:"token,omitempty"` //the temp creds session token
Document string `json:"document,omitempty"` //for EC2 instance document
Signature string `json:"signature,omitempty"` //for EC2 instance document pkcs7 signature
}
Click to show internal directories.
Click to hide internal directories.